Support
=======

There are many ways to get in touch.

File an Issue
-------------

Please `file an issue on GitHub <https://github.com/sporestack/bitcash/issues>`_ if you encounter unexpected behavior or if you would like to request new features.

Send a Tweet
------------

You can tweet `@merc1er <https://twitter.com/merc1er>`_ anytime.

Telegram
--------------

Text Corentin Mercier on Telegram at ``@merc1er``

Email
-----

You can also email `sega01@go-beyond.org <mailto:sega01@go-beyond.org>`_.
Though, if you intend to ask a question that others may benefit from knowing
the answer, please use a more public option.
